@@ -50,8 +50,7 @@ impl RoundtripData for NetifRoundtripData {
             Some(pid) => unsafe {
                 let mut netif = payload.netif_hdr_build(None, None)?;
 
-                let data: &mut gnrc_netif_hdr_t =
-                    ::core::mem::transmute(netif.get_data_mut().as_ptr());
+                let data: &mut gnrc_netif_hdr_t = ::core::mem::transmute(netif.data_mut().as_ptr());
                 data.if_pid = pid.into();
 
                 Some(netif.into())
@@ -107,10 +106,9 @@ impl<N: RoundtripData> RoundtripData for UDPRoundtripDataFull<N> {
             .search_type(GNRC_NETTYPE_UDP)
             .map(|s| {
                 let hdr: &udp_hdr_t = unsafe { &*(s.data.as_ptr() as *const _) };
-                use byteorder::{ByteOrder, NetworkEndian};
                 (
-                    NetworkEndian::read_u16(&unsafe { (*hdr).src_port.u8_ }),
-                    NetworkEndian::read_u16(&unsafe { (*hdr).dst_port.u8_ }),
+                    u16::from_be_bytes(unsafe { (*hdr).src_port.u8_ }),
+                    u16::from_be_bytes(unsafe { (*hdr).dst_port.u8_ }),
                 )
             })
             .unwrap();
