@@ -231,7 +231,9 @@ pub trait MessageSemantics: Sized {
         )
     }
 
+    /// Block to receive a single message
     // No override should be necessary for this, not even for internal impls (see sealing above)
+    #[doc(alias = "msg_receive")]
     fn receive(&self) -> ReceivedMessage<'_, Self> {
         let mut msg = MaybeUninit::uninit();
         unsafe { riot_sys::msg_receive(msg.as_mut_ptr()) };
@@ -242,6 +244,22 @@ pub trait MessageSemantics: Sized {
         }
     }
 
+    /// Receive a single message if one is available in the queue (or another thread is blocking to
+    /// send a message, if no queue is used)
+    #[doc(alias = "msg_try_receive")]
+    fn try_receive(&self) -> Option<ReceivedMessage<'_, Self>> {
+        let mut msg = MaybeUninit::uninit();
+        if unsafe { riot_sys::msg_try_receive(msg.as_mut_ptr()) } == 1 {
+            let msg = unsafe { msg.assume_init() };
+            Some(ReceivedMessage {
+                msg,
+                _phantom: PhantomData,
+            })
+        } else {
+            None
+        }
+    }
+
     /// Interpret a message according to these semantics, then drop it.
     ///
     ///
@@ -392,10 +410,8 @@ impl<'a, S: MessageSemantics> ReceivedMessage<'a, S> {
         let mut transmuted = MaybeUninit::uninit();
         // Hoping that the compiler is clever and doesn't *really* move data around ... then
         // again, it's only 4 byte or a pointer...
-        core::mem::swap(&mut transmuted, unsafe {
-            core::mem::transmute(&mut self.msg.content)
-        });
-        unsafe { transmuted.assume_init() }
+        core::mem::swap(&mut transmuted, core::mem::transmute(&mut self.msg.content));
+        transmuted.assume_init()
     }
 
     pub fn decode<R, F: FnOnce(Sender, TYPE) -> R, TYPE: Send, const TYPENO: u16>(
